==> jc-1.4.0.tar.gz: javax/swing/text/FieldView.h <==
// public class javax.swing.text.FieldView

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 24019b080bec3e58 javax_swing_text_FieldView
// @dep_class a007d47a1e2f730a javax_swing_text_PlainView
// @dep_class b564f56d2f2041c1 javax_swing_text_View

// header file dependencies
// @dep_header javax_swing_text_PlainView

#include "javax/swing/text/PlainView.h"

#ifndef _JC_javax_swing_text_FieldView_H_
#define _JC_javax_swing_text_FieldView_H_

// Forward structure declarations
struct _jc_java_awt_FontMetrics$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Shape$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_text_Element$object;
struct _jc_javax_swing_text_Position__24Bias$object;

// Typedefs
typedef struct _jc_javax_swing_text_FieldView$sub_refs	_jc_javax_swing_text_FieldView$sub_refs;
typedef struct _jc_javax_swing_text_FieldView$sub_nonrefs	_jc_javax_swing_text_FieldView$sub_nonrefs;
typedef struct _jc_javax_swing_text_FieldView$refs	_jc_javax_swing_text_FieldView$refs;
typedef struct _jc_javax_swing_text_FieldView$nonrefs	_jc_javax_swing_text_FieldView$nonrefs;
typedef struct _jc_javax_swing_text_FieldView$object	_jc_javax_swing_text_FieldView$object;

typedef const struct _jc_javax_swing_text_FieldView$vmethods	_jc_javax_swing_text_FieldView$vmethods;
typedef const struct _jc_javax_swing_text_FieldView$vtable	_jc_javax_swing_text_FieldView$vtable;
typedef const struct _jc_javax_swing_text_FieldView$vtype	_jc_javax_swing_text_FieldView$vtype;

// Constructors
extern void _jc_javax_swing_text_FieldView$method$_init$102e066f5c45b34f(_jc_env *, struct _jc_javax_swing_text_FieldView$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_awt_FontMetrics$object *_jc_javax_swing_text_FieldView$method$getFontMetrics$1d113b4b3dbe5474(_jc_env *, struct _jc_javax_swing_text_FieldView$object *);
extern jfloat _jc_javax_swing_text_FieldView$method$getPreferredSpan$8d3c9b3b44df365e(_jc_env *, struct _jc_javax_swing_text_FieldView$object *, jint);
extern jint _jc_javax_swing_text_FieldView$method$getResizeWeight$38b22365441d4e54(_jc_env *, struct _jc_javax_swing_text_FieldView$object *, jint);
extern struct _jc_object *_jc_javax_swing_text_FieldView$method$modelToView$58cd7cb44b36f158(_jc_env *, struct _jc_javax_swing_text_FieldView$object *, jint, struct _jc_object *, struct _jc_javax_swing_text_Position__24Bias$object *);
extern void _jc_javax_swing_text_FieldView$method$paint$4a5b2b5c3e62fdfc(_jc_env *, struct _jc_javax_swing_text_FieldView$object *, struct _jc_java_awt_Graphics$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_FieldView$method_info$getFontMetrics$1d113b4b3dbe5474;
extern _jc_method _jc_javax_swing_text_FieldView$method_info$getPreferredSpan$8d3c9b3b44df365e;
extern _jc_method _jc_javax_swing_text_FieldView$method_info$getResizeWeight$38b22365441d4e54;
extern _jc_method _jc_javax_swing_text_FieldView$method_info$modelToView$58cd7cb44b36f158;
extern _jc_method _jc_javax_swing_text_FieldView$method_info$paint$4a5b2b5c3e62fdfc;

// Virtual methods structure
struct _jc_javax_swing_text_FieldView$vmethods {
	struct _jc_java_awt_FontMetrics$object	*(*getFontMetrics$1d113b4b3dbe5474)(_jc_env *, struct _jc_javax_swing_text_FieldView$object *);
	jfloat	(*getPreferredSpan$8d3c9b3b44df365e)(_jc_env *, struct _jc_javax_swing_text_FieldView$object *, jint);
	jint	(*getResizeWeight$38b22365441d4e54)(_jc_env *, struct _jc_javax_swing_text_FieldView$object *, jint);
	struct _jc_object	*(*modelToView$58cd7cb44b36f158)(_jc_env *, struct _jc_javax_swing_text_FieldView$object *, jint, struct _jc_object *, struct _jc_javax_swing_text_Position__24Bias$object *);
	void	(*paint$4a5b2b5c3e62fdfc)(_jc_env *, struct _jc_javax_swing_text_FieldView$object *, struct _jc_java_awt_Graphics$object *, struct _jc_object *);
};

// Vtable
struct _jc_javax_swing_text_FieldView$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_View$vmethods	javax_swing_text_View;
	_jc_javax_swing_text_PlainView$vmethods	javax_swing_text_PlainView;
	_jc_javax_swing_text_FieldView$vmethods	javax_swing_text_FieldView;
};

// Vtype
struct _jc_javax_swing_text_FieldView$vtype {
	_jc_type			type;
	_jc_javax_swing_text_FieldView$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_FieldView$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_FieldView$refs {
    _jc_javax_swing_text_FieldView$sub_refs	javax_swing_text_FieldView;
    _jc_javax_swing_text_PlainView$sub_refs	javax_swing_text_PlainView;
    _jc_javax_swing_text_View$sub_refs	javax_swing_text_View;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_FieldView$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_FieldView$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_View$sub_nonrefs	javax_swing_text_View;
    _jc_javax_swing_text_PlainView$sub_nonrefs	javax_swing_text_PlainView;
    _jc_javax_swing_text_FieldView$sub_nonrefs	javax_swing_text_FieldView;
};

// Object instance structure
struct _jc_javax_swing_text_FieldView$object {
	_jc_javax_swing_text_FieldView$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_FieldView$vtype	*vtype;
	_jc_javax_swing_text_FieldView$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_FieldView$vtype _jc_javax_swing_text_FieldView$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_FieldView, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_FieldView$class_object;

#endif	/* _JC_javax_swing_text_FieldView_H_ */

==> jc-1.4.5.tar.gz: javax/swing/text/FieldView.h <==
// public class javax.swing.text.FieldView

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 24019b080bec3e58 javax_swing_text_FieldView
// @dep_class a007d47a1e2f730a javax_swing_text_PlainView
// @dep_class b564f56d2f2041c1 javax_swing_text_View

// header file dependencies
// @dep_header javax_swing_text_PlainView

#include "javax/swing/text/PlainView.h"

#ifndef _JC_javax_swing_text_FieldView_H_
#define _JC_javax_swing_text_FieldView_H_

// Forward structure declarations
struct _jc_java_awt_FontMetrics$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Shape$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_text_Element$object;
struct _jc_javax_swing_text_Position__24Bias$object;

// Typedefs
typedef struct _jc_javax_swing_text_FieldView$sub_refs	_jc_javax_swing_text_FieldView$sub_refs;
typedef struct _jc_javax_swing_text_FieldView$sub_nonrefs	_jc_javax_swing_text_FieldView$sub_nonrefs;
typedef struct _jc_javax_swing_text_FieldView$refs	_jc_javax_swing_text_FieldView$refs;
typedef struct _jc_javax_swing_text_FieldView$nonrefs	_jc_javax_swing_text_FieldView$nonrefs;
typedef struct _jc_javax_swing_text_FieldView$object	_jc_javax_swing_text_FieldView$object;

typedef const struct _jc_javax_swing_text_FieldView$vmethods	_jc_javax_swing_text_FieldView$vmethods;
typedef const struct _jc_javax_swing_text_FieldView$vtable	_jc_javax_swing_text_FieldView$vtable;
typedef const struct _jc_javax_swing_text_FieldView$vtype	_jc_javax_swing_text_FieldView$vtype;

// Constructors
extern void _jc_javax_swing_text_FieldView$method$_init$102e066f5c45b34f(_jc_env *, struct _jc_javax_swing_text_FieldView$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_FontMetrics$object *_jc_javax_swing_text_FieldView$method$getFontMetrics$1d113b4b3dbe5474(_jc_env *, struct _jc_javax_swing_text_FieldView$object *) _JC_JCNI_ATTR;
extern jfloat _jc_javax_swing_text_FieldView$method$getPreferredSpan$8d3c9b3b44df365e(_jc_env *, struct _jc_javax_swing_text_FieldView$object *, jint) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_text_FieldView$method$getResizeWeight$38b22365441d4e54(_jc_env *, struct _jc_javax_swing_text_FieldView$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_text_FieldView$method$modelToView$58cd7cb44b36f158(_jc_env *, struct _jc_javax_swing_text_FieldView$object *, jint, struct _jc_object *, struct _jc_javax_swing_text_Position__24Bias$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_text_FieldView$method$paint$4a5b2b5c3e62fdfc(_jc_env *, struct _jc_javax_swing_text_FieldView$object *, struct _jc_java_awt_Graphics$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_FieldView$method_info$getFontMetrics$1d113b4b3dbe5474;
extern _jc_method _jc_javax_swing_text_FieldView$method_info$getPreferredSpan$8d3c9b3b44df365e;
extern _jc_method _jc_javax_swing_text_FieldView$method_info$getResizeWeight$38b22365441d4e54;
extern _jc_method _jc_javax_swing_text_FieldView$method_info$modelToView$58cd7cb44b36f158;
extern _jc_method _jc_javax_swing_text_FieldView$method_info$paint$4a5b2b5c3e62fdfc;

// Virtual methods structure
struct _jc_javax_swing_text_FieldView$vmethods {
	struct _jc_java_awt_FontMetrics$object	*(*getFontMetrics$1d113b4b3dbe5474)(_jc_env *, struct _jc_javax_swing_text_FieldView$object *) _JC_JCNI_ATTR;
	jfloat	(*getPreferredSpan$8d3c9b3b44df365e)(_jc_env *, struct _jc_javax_swing_text_FieldView$object *, jint) _JC_JCNI_ATTR;
	jint	(*getResizeWeight$38b22365441d4e54)(_jc_env *, struct _jc_javax_swing_text_FieldView$object *, jint) _JC_JCNI_ATTR;
	struct _jc_object	*(*modelToView$58cd7cb44b36f158)(_jc_env *, struct _jc_javax_swing_text_FieldView$object *, jint, struct _jc_object *, struct _jc_javax_swing_text_Position__24Bias$object *) _JC_JCNI_ATTR;
	void	(*paint$4a5b2b5c3e62fdfc)(_jc_env *, struct _jc_javax_swing_text_FieldView$object *, struct _jc_java_awt_Graphics$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_text_FieldView$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_View$vmethods	javax_swing_text_View;
	_jc_javax_swing_text_PlainView$vmethods	javax_swing_text_PlainView;
	_jc_javax_swing_text_FieldView$vmethods	javax_swing_text_FieldView;
};

// Vtype
struct _jc_javax_swing_text_FieldView$vtype {
	_jc_type			type;
	_jc_javax_swing_text_FieldView$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_FieldView$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_FieldView$refs {
    _jc_javax_swing_text_FieldView$sub_refs	javax_swing_text_FieldView;
    _jc_javax_swing_text_PlainView$sub_refs	javax_swing_text_PlainView;
    _jc_javax_swing_text_View$sub_refs	javax_swing_text_View;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_FieldView$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_FieldView$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_View$sub_nonrefs	javax_swing_text_View;
    _jc_javax_swing_text_PlainView$sub_nonrefs	javax_swing_text_PlainView;
    _jc_javax_swing_text_FieldView$sub_nonrefs	javax_swing_text_FieldView;
};

// Object instance structure
struct _jc_javax_swing_text_FieldView$object {
	_jc_javax_swing_text_FieldView$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_FieldView$vtype	*vtype;
	_jc_javax_swing_text_FieldView$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_FieldView$vtype _jc_javax_swing_text_FieldView$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_FieldView, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_FieldView$class_object;

#endif	/* _JC_javax_swing_text_FieldView_H_ */
